"use client"

import type React from "react"

import { useState, useEffect, useCallback, useRef } from "react"
import { CheckCircle, XCircle, Clock, ChevronRight, AlertTriangle, Award, Volume2, VolumeX, Upload } from "lucide-react"
import { useAuth } from "@/context/auth-context"
import { motion, AnimatePresence } from "framer-motion"
import { Progress } from "@/components/ui/progress"
import { Card, CardContent } from "@/components/ui/card"
import { Button } from "@/components/ui/button"
import { Badge } from "@/components/ui/badge"
import Timer from "./timer"

// Types based on the provided JSON format
type QuizQuestion = {
  qid: string
  question: string
  correct_answer: string
  explanation: string
  image_url: string
  suggestion: string[]
  audio_url?: string // URL vers un fichier audio préenregistré
}

type QuizProps = {
  title: string
  questions: QuizQuestion[]
  type: "exercise" | "exam"
}

export default function Quiz({ title, questions, type }: QuizProps) {
  const { user } = useAuth()
  const [currentQuestionIndex, setCurrentQuestionIndex] = useState(0)
  const [selectedAnswer, setSelectedAnswer] = useState<string | null>(null)
  const [textInputValue, setTextInputValue] = useState<string>("")
  const [isAnswerSubmitted, setIsAnswerSubmitted] = useState(false)
  const [isTimeUp, setIsTimeUp] = useState(false)
  const [userAnswers, setUserAnswers] = useState<{ questionId: string; answer: string | null; isCorrect: boolean }[]>(
    [],
  )
  const [isQuizCompleted, setIsQuizCompleted] = useState(false)
  const [isSavingScore, setIsSavingScore] = useState(false)
  const [hasSavedScore, setHasSavedScore] = useState(false)
  const [scoreSaved, setScoreSaved] = useState(false)
  const [score, setScore] = useState(0)
  const [totalScore, setTotalScore] = useState(0)
  const [scaledScore, setScaledScore] = useState(0)
  const [noQuestions, setNoQuestions] = useState(false)
  const [questionNotFound, setQuestionNotFound] = useState(false)
  const [timerKey, setTimerKey] = useState(0)
  const [viewMode, setViewMode] = useState<"grid" | "list">("grid")

  // États pour la lecture audio
  const [soundEnabled, setSoundEnabled] = useState(true)
  const [isAudioPlaying, setIsAudioPlaying] = useState(false)
  const [isTimerActive, setIsTimerActive] = useState(false)
  const audioRef = useRef<HTMLAudioElement | null>(null)

  // Ajouter un état pour suivre si le code s'exécute côté client
  const [isClient, setIsClient] = useState(false)

  // Ajouter cet useEffect au début du composant, juste après les déclarations d'état
  useEffect(() => {
    setIsClient(true)
  }, [])

  // Vérifier si des questions sont disponibles
  const checkQuestionsAvailability = useCallback(() => {
    if (!questions || questions.length === 0) {
      setNoQuestions(true)
    } else {
      setNoQuestions(false)
    }
  }, [questions])

  // Vérifier si la question actuelle existe
  const checkCurrentQuestion = useCallback(() => {
    if (questions && !questions[currentQuestionIndex]) {
      setQuestionNotFound(true)
    } else {
      setQuestionNotFound(false)
    }
  }, [questions, currentQuestionIndex])

  useEffect(() => {
    checkQuestionsAvailability()
  }, [checkQuestionsAvailability])

  useEffect(() => {
    checkCurrentQuestion()
  }, [checkCurrentQuestion])

  // Définir currentQuestion après les vérifications
  const currentQuestion = questions[currentQuestionIndex]

  // Format the question text to handle newlines and options
  const formatQuestionText = useCallback((text: string) => {
    // Vérifier si le texte est défini
    if (!text || typeof text !== "string") {
      return ""
    }
    // Return the entire question text to preserve all newlines
    return text
  }, [])

  // Parse the options from the question text if needed
  const parseOptions = useCallback((question: QuizQuestion) => {
    // Vérifier si la question est définie
    if (!question || (!question.suggestion && (!question.question || typeof question.question !== "string"))) {
      return []
    }

    // If suggestions are already provided, use them
    if (question.suggestion) {
      // Handle string format (for backward compatibility)
      if (typeof question.suggestion === "string") {
        // If it's "input text", return empty array as it will be handled by input field
        if (question.suggestion === "input text") {
          return []
        }
        // Otherwise convert to array
        return [question.suggestion]
      }
      // Handle array format
      if (Array.isArray(question.suggestion) && question.suggestion.length > 0) {
        return question.suggestion
      }
    }

    // Otherwise, try to parse from question text
    // Look for lines that start with A., B., C., etc.
    const optionLines =
      question.question && typeof question.question === "string"
        ? question.question.split("\n").filter((line) => /^[A-Z]\./.test(line))
        : []
    if (optionLines.length > 0) {
      return optionLines.map((option) => {
        // Remove the prefix like "A. " or "B. "
        const match = option.match(/^[A-Z]\.\s(.+)/)
        return match ? match[1] : option
      })
    }

    return []
  }, [])

  // Modifier la fonction stopSpeaking pour utiliser isClient
  const stopSpeaking = useCallback(() => {
    if (isClient && "speechSynthesis" in window) {
      window.speechSynthesis.cancel()
    }
    if (audioRef.current) {
      audioRef.current.pause()
    }
  }, [isClient])

  // Fonction pour estimer le temps de lecture d'un texte (en millisecondes)
  const estimateReadingTime = useCallback((text: string) => {
    // En moyenne, on lit environ 15 caractères par seconde à voix haute
    const charsPerSecond = 15
    return Math.max(3000, (text.length / charsPerSecond) * 1000)
  }, [])

  // Modifier la fonction speakQuestion pour utiliser isClient et gérer le timer
  const speakQuestion = useCallback(() => {
    if (!currentQuestion) return

    // Désactiver le timer pendant la lecture
    setIsTimerActive(false)

    // Arrêter toute lecture en cours
    stopSpeaking()

    // Si le son est désactivé, activer directement le timer
    if (!soundEnabled) {
      console.log("Son désactivé, activation directe du timer")
      setIsTimerActive(true)
      return
    }

    // Fonction commune pour gérer la fin de l'audio
    const handleAudioEnd = () => {
      console.log("Audio terminé, activation du timer")
      setIsAudioPlaying(false)
      setIsTimerActive(true)
    }

    // Fonction commune pour gérer les erreurs audio
    const handleAudioError = (errorMsg: string) => {
      console.error(errorMsg)
      setIsAudioPlaying(false)
      setIsTimerActive(true)
    }

    // Vérifier si la question a un audio préenregistré
    if (currentQuestion.audio_url) {
      if (!audioRef.current) {
        audioRef.current = new Audio(currentQuestion.audio_url)
      } else {
        audioRef.current.src = currentQuestion.audio_url
      }

      audioRef.current.onended = handleAudioEnd
      audioRef.current.onerror = () => handleAudioError("Erreur lors du chargement de l'audio")

      // Ajouter un événement pour suivre le début de la lecture
      audioRef.current.onplay = () => {
        console.log("Lecture audio démarrée")
      }

      audioRef.current.play().catch((err) => {
        handleAudioError(`Erreur lors de la lecture audio: ${err}`)
      })
    } else if (isClient && "speechSynthesis" in window) {
      // Utiliser l'API TTS avec des paramètres améliorés pour une voix plus naturelle
      const utterance = new SpeechSynthesisUtterance()
      utterance.text = formatQuestionText(currentQuestion.question)
      utterance.lang = "fr-FR"

      // Paramètres pour une voix plus naturelle
      utterance.rate = 0.9 // Vitesse légèrement plus rapide mais toujours compréhensible
      utterance.pitch = 1.05 // Ton légèrement plus élevé pour plus de dynamisme
      utterance.volume = 1.0 // Volume maximal

      // Sélectionner la meilleure voix française disponible
      const voices = window.speechSynthesis.getVoices()
      console.log(
        "Voix disponibles:",
        voices.map((v) => `${v.name} (${v.lang})`),
      )

      // Essayer de trouver une voix premium ou de haute qualité d'abord
      const premiumVoices = voices.filter(
        (voice) =>
          voice.lang.includes("fr") &&
          (voice.name.includes("Premium") ||
            voice.name.includes("Enhanced") ||
            voice.name.includes("Neural") ||
            voice.name.includes("Plus")),
      )

      // Si des voix premium sont disponibles, utiliser la première
      if (premiumVoices.length > 0) {
        console.log("Utilisation d'une voix premium:", premiumVoices[0].name)
        utterance.voice = premiumVoices[0]
      } else {
        // Sinon, utiliser n'importe quelle voix française
        const frenchVoice = voices.find((voice) => voice.lang.includes("fr"))
        if (frenchVoice) {
          console.log("Utilisation d'une voix standard:", frenchVoice.name)
          utterance.voice = frenchVoice
        }
      }

      utterance.onend = handleAudioEnd
      utterance.onerror = () => handleAudioError("Erreur lors de la synthèse vocale")

      window.speechSynthesis.speak(utterance)

      // Fallback au cas où l'événement onend ne se déclenche pas
      const estimatedDuration = estimateReadingTime(utterance.text)
      console.log(`Temps de lecture estimé: ${estimatedDuration / 1000} secondes`)

      setTimeout(() => {
        if (isAudioPlaying) {
          console.log("Fin estimée de la lecture, activation du timer")
          setIsAudioPlaying(false)
          setIsTimerActive(true)
        }
      }, estimatedDuration)
    } else {
      // Si aucune méthode de lecture n'est disponible, activer directement le timer
      console.log("Aucune méthode de lecture disponible, activation directe du timer")
      setIsAudioPlaying(false)
      setIsTimerActive(true)
    }
  }, [currentQuestion, soundEnabled, stopSpeaking, formatQuestionText, isClient, isAudioPlaying, estimateReadingTime])

  // Modifier l'initialisation des voix pour utiliser isClient
  useEffect(() => {
    if (isClient && "speechSynthesis" in window) {
      window.speechSynthesis.getVoices()
    }
  }, [isClient])

  // Lire automatiquement la question quand elle change
  useEffect(() => {
    if (soundEnabled && !isAnswerSubmitted && currentQuestion) {
      // Petit délai pour laisser l'animation se terminer
      const timer = setTimeout(() => {
        speakQuestion()
      }, 500)

      return () => clearTimeout(timer)
    }
  }, [currentQuestionIndex, soundEnabled, isAnswerSubmitted, speakQuestion, currentQuestion])

  // Arrêter la lecture audio lors du changement de question
  useEffect(() => {
    stopSpeaking()
  }, [currentQuestionIndex, stopSpeaking])

  // Function to check if the question requires text input
  const isTextInputQuestion = useCallback((question: QuizQuestion) => {
    // Handle both string and array formats
    return (
      question.suggestion && 
      ((Array.isArray(question.suggestion) && question.suggestion.length === 1 && question.suggestion[0] === "input text") ||
       question.suggestion === "input text")
    )
  }, [])

  // Déplacez la définition de handleSubmit après la définition de currentQuestion
  const handleSubmit = useCallback(() => {
    if (!currentQuestion) return

    // For text input questions, use the textInputValue as the answer
    const answerToSubmit = isTextInputQuestion(currentQuestion) ? textInputValue : selectedAnswer

    // Vérifier si la réponse sélectionnée est correcte
    let isCorrect = false
    if (answerToSubmit) {
      // Convertir la réponse correcte en minuscules pour la comparaison
      const correctAnswer = currentQuestion.correct_answer.toLowerCase()

      // Pour les questions à saisie de texte, comparer directement avec la réponse correcte
      if (isTextInputQuestion(currentQuestion)) {
        isCorrect = answerToSubmit.toLowerCase() === correctAnswer.toLowerCase()
      } else {
        // Vérifier si la réponse est correcte (soit par lettre a,b,c soit par texte complet)
        isCorrect =
          answerToSubmit.toLowerCase() === correctAnswer ||
          // Si la réponse correcte est une lettre (a, b, c) et que nous avons des suggestions
          (correctAnswer.length === 1 &&
            correctAnswer >= "a" &&
            correctAnswer <= "z" &&
            currentQuestion.suggestion &&
            answerToSubmit.toLowerCase() ===
              currentQuestion.suggestion[correctAnswer.charCodeAt(0) - "a".charCodeAt(0)].toLowerCase())
      }
    }

    setUserAnswers((prev) => [...prev, { questionId: currentQuestion.qid, answer: answerToSubmit, isCorrect }])

    setIsAnswerSubmitted(true)

    // Arrêter la lecture audio si elle est en cours
    stopSpeaking()
  }, [selectedAnswer, currentQuestion, userAnswers, stopSpeaking, parseOptions])

  // Assurez-vous que useEffect utilisant handleSubmit est placé après sa définition
  useEffect(() => {
    if (isTimeUp && !isAnswerSubmitted) {
      handleSubmit()
    }
  }, [isTimeUp, isAnswerSubmitted, handleSubmit])

  const handleAnswerSelect = (answer: string) => {
    if (!isAnswerSubmitted) {
      setSelectedAnswer(answer)
    }
  }

  const handleNext = useCallback(() => {
    // Arrêter la lecture audio si elle est en cours
    stopSpeaking()

    if (currentQuestionIndex < questions.length - 1) {
      setCurrentQuestionIndex(currentQuestionIndex + 1)
      setSelectedAnswer(null)
      setTextInputValue("")
      setIsAnswerSubmitted(false)
      setIsTimeUp(false)
      setTimerKey((prevKey) => prevKey + 1)
    } else {
      setIsQuizCompleted(true)
    }
  }, [currentQuestionIndex, questions.length, timerKey, stopSpeaking])

  // Fonction pour gérer la fin du timer
  const handleTimeUp = useCallback(() => {
    // Marquer le temps comme écoulé
    setIsTimeUp(true)

    // Enregistrer cette question comme fausse sans sélectionner de réponse
    if (!isAnswerSubmitted) {
      setUserAnswers((prev) => [...prev, { questionId: currentQuestion.qid, answer: null, isCorrect: false }])

      // Passer directement à la question suivante après un court délai
      setTimeout(() => {
        if (currentQuestionIndex < questions.length - 1) {
          // Passer à la question suivante
          setCurrentQuestionIndex(currentQuestionIndex + 1)
          setSelectedAnswer(null)
          setTextInputValue("")
          setIsAnswerSubmitted(false)
          setIsTimeUp(false)
          setTimerKey((prevKey) => prevKey + 1) // Réinitialiser le timer
        } else {
          // C'était la dernière question, terminer le quiz
          setIsQuizCompleted(true)
        }
      }, 1000) // 1 seconde de délai
    }
  }, [currentQuestion, currentQuestionIndex, questions.length, isAnswerSubmitted])

  // La logique de passage automatique à la question suivante est maintenant gérée directement dans handleTimeUp

  // Sauvegarder le score dans la base de données
  const saveScore = async (score: number, maxScore: number) => {
    if (!user || hasSavedScore || !currentQuestion) return

    try {
      setIsSavingScore(true)

      const response = await fetch("/api/scores/save", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          userId: user.id,
          examType: type,
          examId: type === "exam" ? "exam-standard" : currentQuestion.qid.split("-")[0],
          score,
          maxScore,
          answers: userAnswers,
        }),
      })

      if (!response.ok) {
        throw new Error("Failed to save score")
      }
      setHasSavedScore(true)
      setScoreSaved(true)
    } catch (error) {
      console.error("Error saving score:", error)
    } finally {
      setIsSavingScore(false)
    }
  }

  const saveScoreMemoized = useCallback(saveScore, [user, hasSavedScore, type, currentQuestion, userAnswers])

  useEffect(() => {
    if (isQuizCompleted) {
      const calculatedScore = userAnswers.filter((answer) => answer.isCorrect).length
      const calculatedTotalScore = questions.length
      const calculatedScaledScore = Math.round((calculatedScore / questions.length) * 50)

      setScore(calculatedScore)
      setTotalScore(calculatedTotalScore)
      setScaledScore(calculatedScaledScore)

      saveScoreMemoized(calculatedScore, calculatedTotalScore)
    }
  }, [isQuizCompleted, userAnswers, questions, saveScoreMemoized])

  if (noQuestions) {
    return (
      <div className="container mx-auto px-4 py-8 max-w-4xl">
        <Card className="overflow-hidden border-none shadow-lg">
          <CardContent className="p-0">
            <div className="bg-gradient-to-r from-route-blue/10 to-route-blue/5 p-8 text-center">
              <AlertTriangle className="h-16 w-16 text-route-blue mx-auto mb-4" />
              <h2 className="text-2xl font-bold text-gray-800 mb-4">Aucune question disponible</h2>
              <p className="text-gray-600 mb-6">
                Nous n'avons pas trouvé de questions pour ce quiz. Veuillez essayer un autre chapitre.
              </p>
              <Button onClick={() => (window.location.href = "/")} className="bg-route-blue hover:bg-route-blue/90">
                Retour à l'accueil
              </Button>
            </div>
          </CardContent>
        </Card>
      </div>
    )
  }

  // Vérifier si la question actuelle existe
  if (questionNotFound) {
    return (
      <div className="container mx-auto px-4 py-8 max-w-4xl">
        <Card className="overflow-hidden border-none shadow-lg">
          <CardContent className="p-0">
            <div className="bg-gradient-to-r from-route-red/10 to-route-red/5 p-8 text-center">
              <AlertTriangle className="h-16 w-16 text-route-red mx-auto mb-4" />
              <h2 className="text-2xl font-bold text-gray-800 mb-4">Question non trouvée</h2>
              <p className="text-gray-600 mb-6">
                Une erreur s'est produite lors du chargement de la question. Veuillez réessayer.
              </p>
              <Button onClick={() => (window.location.href = "/")} className="bg-route-red hover:bg-route-red/90">
                Retour à l'accueil
              </Button>
            </div>
          </CardContent>
        </Card>
      </div>
    )
  }

  const progress = ((currentQuestionIndex + 1) / questions.length) * 100

  if (isQuizCompleted) {
    const passRate = (score / totalScore) * 100
    const isPassed = passRate >= 70

    return (
      <div className="container mx-auto px-4 py-8 max-w-4xl">
        <Card className="overflow-hidden border-none shadow-lg">
          <CardContent className="p-0">
            <div
              className={`p-8 text-center ${isPassed ? "bg-gradient-to-r from-route-green/10 to-route-green/5" : "bg-gradient-to-r from-route-red/10 to-route-red/5"}`}
            >
              <div
                className="w-24 h-24 rounded-full flex items-center justify-center mx-auto mb-4 border-4 border-white shadow-md"
                style={{ backgroundColor: isPassed ? "#34C759" : "#FF3B30" }}
              >
                <span className="text-3xl font-bold text-white">{Math.round(passRate)}%</span>
              </div>

              <h2 className="text-3xl font-bold mb-2">{isPassed ? "Félicitations !" : "Essayez encore"}</h2>
              <p className="text-gray-600 mb-6">
                Vous avez obtenu {score} bonnes réponses sur {totalScore} questions
              </p>

              <div className="grid grid-cols-2 gap-6 mb-8">
                <div className="bg-white rounded-lg p-6 shadow-md">
                  <div className="flex items-center">
                    <CheckCircle className="h-8 w-8 text-route-green mr-3" />
                    <div>
                      <p className="font-medium text-gray-500">Bonnes réponses</p>
                      <p className="text-3xl font-bold">{score}</p>
                    </div>
                  </div>
                </div>
                <div className="bg-white rounded-lg p-6 shadow-md">
                  <div className="flex items-center">
                    <XCircle className="h-8 w-8 text-route-red mr-3" />
                    <div>
                      <p className="font-medium text-gray-500">Mauvaises réponses</p>
                      <p className="text-3xl font-bold">{totalScore - score}</p>
                    </div>
                  </div>
                </div>
              </div>

              <div className="flex justify-center mb-8">
                <Button
                  onClick={() => (window.location.href = "/")}
                  className={
                    isPassed ? "bg-route-green hover:bg-route-green/90" : "bg-route-blue hover:bg-route-blue/90"
                  }
                  size="lg"
                >
                  Retour à l'accueil
                </Button>
              </div>
            </div>

            <div className="p-8">
              <div className="flex justify-between items-center mb-6">
                <h3 className="text-2xl font-bold">Récapitulatif détaillé</h3>
                <div className="flex items-center space-x-2 bg-gray-100 rounded-lg p-1">
                  <Button
                    variant={viewMode === "grid" ? "default" : "ghost"}
                    size="sm"
                    onClick={() => setViewMode("grid")}
                    className={viewMode === "grid" ? "bg-route-blue" : ""}
                  >
                    Grille
                  </Button>
                  <Button
                    variant={viewMode === "list" ? "default" : "ghost"}
                    size="sm"
                    onClick={() => setViewMode("list")}
                    className={viewMode === "list" ? "bg-route-blue" : ""}
                  >
                    Liste
                  </Button>
                </div>
              </div>

              {viewMode === "grid" ? (
                <div className="space-y-6">
                  {questions.map((question, index) => {
                    const userAnswer = userAnswers.find((a) => a.questionId === question.qid)
                    const isCorrect = userAnswer?.isCorrect || false

                    return (
                      <Card
                        key={question.qid}
                        className={`overflow-hidden border-l-4 ${isCorrect ? "border-l-route-green" : "border-l-route-red"}`}
                      >
                        <CardContent className="p-6">
                          <div className="flex items-start gap-4">
                            <div
                              className={`w-8 h-8 rounded-full flex items-center justify-center flex-shrink-0 ${isCorrect ? "bg-route-green/10" : "bg-route-red/10"}`}
                            >
                              {isCorrect ? (
                                <CheckCircle className="h-5 w-5 text-route-green" />
                              ) : (
                                <XCircle className="h-5 w-5 text-route-red" />
                              )}
                            </div>
                            <div className="flex-1">
                              <div className="flex items-center mb-2">
                                <Badge variant="outline" className="mr-2">
                                  Question {index + 1}
                                </Badge>
                                <h4 className="font-medium">{formatQuestionText(question.question)}</h4>
                              </div>

                              {question.image_url && (
                                <div className="mb-4 mt-3">
                                  <img
                                    src={question.image_url || "/placeholder.svg"}
                                    alt="Question illustration"
                                    className="max-h-48 object-contain rounded-md border border-gray-200"
                                  />
                                </div>
                              )}

                              <div className="mt-4 space-y-3 bg-gray-50 p-4 rounded-md">
                                <div>
                                  <p className="text-sm font-medium text-gray-500">Votre réponse:</p>
                                  <p className={`font-medium ${isCorrect ? "text-route-green" : "text-route-red"}`}>
                                    {userAnswer?.answer || "Pas de réponse"}
                                  </p>
                                </div>

                                {!isCorrect && (
                                  <div>
                                    <p className="text-sm font-medium text-gray-500">Réponse correcte:</p>
                                    <p className="font-medium text-route-green">
                                      {question.correct_answer.length === 1 &&
                                      question.correct_answer >= "a" &&
                                      question.correct_answer <= "z" &&
                                      question.suggestion
                                        ? question.suggestion[question.correct_answer.charCodeAt(0) - "a".charCodeAt(0)]
                                        : question.correct_answer}
                                    </p>
                                  </div>
                                )}

                                {question.explanation && (
                                  <div className="pt-2 mt-2 border-t border-gray-200">
                                    <p className="text-sm font-medium text-gray-500">Explication:</p>
                                    <p className="text-gray-700">{question.explanation}</p>
                                  </div>
                                )}
                              </div>
                            </div>
                          </div>
                        </CardContent>
                      </Card>
                    )
                  })}
                </div>
              ) : (
                <div className="border rounded-lg overflow-hidden">
                  <table className="w-full">
                    <thead className="bg-gray-50">
                      <tr>
                        <th className="px-4 py-3 text-left text-sm font-medium text-gray-500">N°</th>
                        <th className="px-4 py-3 text-left text-sm font-medium text-gray-500">Question</th>
                        <th className="px-4 py-3 text-left text-sm font-medium text-gray-500">Votre réponse</th>
                        <th className="px-4 py-3 text-left text-sm font-medium text-gray-500">Réponse correcte</th>
                        <th className="px-4 py-3 text-left text-sm font-medium text-gray-500">Résultat</th>
                      </tr>
                    </thead>
                    <tbody className="divide-y divide-gray-200">
                      {questions.map((question, index) => {
                        const userAnswer = userAnswers.find((a) => a.questionId === question.qid)
                        const isCorrect = userAnswer?.isCorrect || false

                        return (
                          <tr key={question.qid} className={isCorrect ? "bg-route-green/5" : "bg-route-red/5"}>
                            <td className="px-4 py-3 text-sm">{index + 1}</td>
                            <td className="px-4 py-3 text-sm">
                              <div className="font-medium whitespace-pre-line">
                                {formatQuestionText(question.question)}
                              </div>
                              {question.explanation && (
                                <div className="text-xs text-gray-500 mt-1">
                                  <span className="font-medium">Explication:</span> {question.explanation}
                                </div>
                              )}
                            </td>
                            <td className="px-4 py-3 text-sm">
                              <span
                                className={isCorrect ? "text-route-green font-medium" : "text-route-red font-medium"}
                              >
                                {userAnswer?.answer || "Pas de réponse"}
                              </span>
                            </td>
                            <td className="px-4 py-3 text-sm text-route-green font-medium">
                              {question.correct_answer.length === 1 &&
                              question.correct_answer >= "a" &&
                              question.correct_answer <= "z" &&
                              question.suggestion
                                ? question.suggestion[question.correct_answer.charCodeAt(0) - "a".charCodeAt(0)]
                                : question.correct_answer}
                            </td>
                            <td className="px-4 py-3 text-sm">
                              {isCorrect ? (
                                <div className="flex items-center">
                                  <CheckCircle className="h-5 w-5 text-route-green mr-1" />
                                  <span className="text-route-green font-medium">Correct</span>
                                </div>
                              ) : (
                                <div className="flex items-center">
                                  <XCircle className="h-5 w-5 text-route-red mr-1" />
                                  <span className="text-route-red font-medium">Incorrect</span>
                                </div>
                              )}
                            </td>
                          </tr>
                        )
                      })}
                    </tbody>
                  </table>
                </div>
              )}
            </div>
          </CardContent>
        </Card>
      </div>
    )
  }

  const options = parseOptions(currentQuestion)
  const questionText = formatQuestionText(currentQuestion.question)

  // Fonction pour gérer l'upload d'un fichier audio (pour les administrateurs)
  const handleAudioUpload = async (event: React.ChangeEvent<HTMLInputElement>) => {
    if (!event.target.files || event.target.files.length === 0 || !user || user.role !== "admin") return

    const file = event.target.files[0]
    if (!file.type.startsWith("audio/")) {
      alert("Veuillez sélectionner un fichier audio")
      return
    }

    // Pour la démonstration, nous allons simplement créer une URL locale
    const audioUrl = URL.createObjectURL(file)

    // Mettre à jour la question actuelle avec l'URL audio temporaire
    questions[currentQuestionIndex] = {
      ...currentQuestion,
      audio_url: audioUrl,
    }

    // Forcer la mise à jour du composant
    setCurrentQuestionIndex(currentQuestionIndex)

    // Lire l'audio
    if (audioRef.current) {
      audioRef.current.src = audioUrl
      audioRef.current.play().catch((err) => console.error("Erreur lors de la lecture audio:", err))
    }
  }

  return (
    <div className="container mx-auto px-4 py-8 max-w-4xl">
      <Card className="overflow-hidden border-none shadow-lg">
        <CardContent className="p-0">
          {/* Header avec progression */}
          <div className="bg-white border-b p-6">
            <div className="flex justify-between items-center mb-4">
              <div>
                <h2 className="text-xl font-bold">{title}</h2>
                <p className="text-gray-500">
                  Question {currentQuestionIndex + 1} sur {questions.length}
                </p>
              </div>
              <div className="flex items-center gap-4">
                <Button
                  variant="ghost"
                  size="sm"
                  className={`flex items-center gap-2 ${soundEnabled ? "text-route-blue" : "text-gray-500"}`}
                  onClick={() => setSoundEnabled(!soundEnabled)}
                  title={soundEnabled ? "Désactiver le son" : "Activer le son"}
                >
                  {soundEnabled ? <Volume2 className="h-4 w-4" /> : <VolumeX className="h-4 w-4" />}
                </Button>
                {user && user.role === "admin" && (
                  <div className="relative">
                    <input
                      type="file"
                      accept="audio/*"
                      onChange={handleAudioUpload}
                      className="absolute inset-0 w-full h-full opacity-0 cursor-pointer"
                      title="Télécharger un fichier audio pour cette question"
                    />
                    <Button
                      variant="outline"
                      size="sm"
                      className="flex items-center gap-2"
                      title="Télécharger un fichier audio pour cette question"
                    >
                      <Upload className="h-4 w-4" />
                      <span className="hidden sm:inline">Audio</span>
                    </Button>
                  </div>
                )}
                <div className="flex items-center">
                  <Clock className="h-5 w-5 text-gray-500 mr-2" />
                  <Timer
                    duration={30}
                    onTimeUp={handleTimeUp}
                    isActive={isTimerActive && !isAnswerSubmitted}
                    key={timerKey}
                  />
                </div>
              </div>
            </div>
            <Progress value={progress} className="h-2" />
          </div>

          {/* Contenu de la question */}
          <div className="p-6">
            <AnimatePresence mode="wait">
              <motion.div
                key={currentQuestionIndex}
                initial={{ opacity: 0, y: 20 }}
                animate={{ opacity: 1, y: 0 }}
                exit={{ opacity: 0, y: -20 }}
                transition={{ duration: 0.3 }}
              >
                <div className="mb-6">
                  <h3 className="text-lg font-medium mb-4 whitespace-pre-line">{questionText}</h3>

                  {currentQuestion.image_url && (
                    <div className="mb-6 rounded-lg overflow-hidden border border-gray-200">
                      <img
                        src={currentQuestion.image_url || "/placeholder.svg"}
                        alt="Question illustration"
                        className="w-full max-h-64 object-contain"
                      />
                    </div>
                  )}

                  {/* Élément audio caché pour la lecture des fichiers audio préenregistrés */}
                  <audio ref={audioRef} className="hidden" />
                </div>

                {/* Options de réponse */}
                <div className="space-y-3 mb-6">
                  {isTextInputQuestion(currentQuestion) ? (
                    <div className="relative p-4 rounded-lg border-2 border-gray-200 bg-white">
                      <input
                        type="text"
                        value={textInputValue}
                        onChange={(e) => setTextInputValue(e.target.value)}
                        placeholder="Entrez votre réponse ici"
                        className="w-full p-2 border border-gray-300 rounded focus:outline-none focus:ring-2 focus:ring-route-blue"
                        disabled={isAnswerSubmitted}
                      />
                      {isAnswerSubmitted && (
                        <div className="mt-4 flex items-center">
                          <div className="font-medium mr-2">Réponse correcte:</div>
                          <div className="text-route-green font-medium">{currentQuestion.correct_answer}</div>
                          {textInputValue.toLowerCase() === currentQuestion.correct_answer.toLowerCase() ? (
                            <CheckCircle className="h-5 w-5 text-route-green ml-2" />
                          ) : (
                            <XCircle className="h-5 w-5 text-route-red ml-2" />
                          )}
                        </div>
                      )}
                    </div>
                  ) : (
                    options.map((option, index) => {
                      const optionLetter = String.fromCharCode(65 + index).toLowerCase() // Convert index to a, b, c...
                      const isSelected = selectedAnswer === option
                      const isCorrect =
                        currentQuestion.correct_answer.toLowerCase() === optionLetter ||
                        currentQuestion.correct_answer.toLowerCase() === option.toLowerCase()

                      let className = "relative flex items-center p-4 rounded-lg border-2 transition-all cursor-pointer"

                      if (isAnswerSubmitted) {
                        if (isCorrect) {
                          className += " border-route-green bg-route-green/5"
                        } else if (isSelected && !isCorrect) {
                          className += " border-route-red bg-route-red/5"
                        } else {
                          className += " border-gray-200 bg-white"
                        }
                      } else if (isSelected) {
                        className += " border-route-blue bg-route-blue/5"
                      } else {
                        className += " border-gray-200 hover:border-gray-300 hover:bg-gray-50"
                      }

                      return (
                        <div key={index} className={className} onClick={() => handleAnswerSelect(option)}>
                          <div
                            className={`w-8 h-8 rounded-full flex items-center justify-center mr-3 flex-shrink-0 ${
                              isSelected
                                ? isAnswerSubmitted
                                  ? isCorrect
                                    ? "bg-route-green"
                                    : "bg-route-red"
                                  : "bg-route-blue"
                                : "bg-gray-200"
                            }`}
                          >
                            <span className={`font-medium ${isSelected ? "text-white" : "text-gray-700"}`}>
                              {String.fromCharCode(65 + index)}
                            </span>
                          </div>
                          <span className="flex-1">{option}</span>

                          {isAnswerSubmitted && (
                            <div className="absolute right-4">
                              {isCorrect && <CheckCircle className="h-5 w-5 text-route-green" />}
                              {isSelected && !isCorrect && <XCircle className="h-5 w-5 text-route-red" />}
                            </div>
                          )}
                        </div>
                      )
                    })
                  )}
                </div>

                {/* Explication (si la réponse est soumise) */}
                {isAnswerSubmitted && currentQuestion.explanation && (
                  <motion.div
                    initial={{ opacity: 0, height: 0 }}
                    animate={{ opacity: 1, height: "auto" }}
                    transition={{ duration: 0.3 }}
                    className="mb-6 bg-gray-50 border border-gray-200 rounded-lg p-4"
                  >
                    <h4 className="font-medium text-route-blue mb-2">Explication :</h4>
                    <p className="text-gray-700 whitespace-pre-line">{currentQuestion.explanation}</p>
                  </motion.div>
                )}

                {/* Boutons d'action */}
                <div className="flex justify-between">
                  {!isAnswerSubmitted ? (
                    <Button
                      onClick={handleSubmit}
                      disabled={isTextInputQuestion(currentQuestion) ? !textInputValue : !selectedAnswer}
                      className={
                        (isTextInputQuestion(currentQuestion) ? textInputValue : selectedAnswer)
                          ? "bg-route-blue hover:bg-route-blue/90"
                          : "bg-gray-200 text-gray-400 cursor-not-allowed"
                      }
                      size="lg"
                    >
                      Valider ma réponse
                    </Button>
                  ) : (
                    <Button onClick={handleNext} className="bg-route-blue hover:bg-route-blue/90" size="lg">
                      {currentQuestionIndex === questions.length - 1 ? (
                        <>
                          Voir les résultats
                          <Award className="ml-2 h-5 w-5" />
                        </>
                      ) : (
                        <>
                          Question suivante
                          <ChevronRight className="ml-2 h-5 w-5" />
                        </>
                      )}
                    </Button>
                  )}
                </div>
              </motion.div>
            </AnimatePresence>
          </div>
        </CardContent>
      </Card>
    </div>
  )
}
